==> cohesity_management_sdk-1.7.0.tar.gz: cohesity_management_sdk-1.7.0/cohesity_management_sdk/models/environment_list_protection_sources_registration_info_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2021 Cohesity Inc.

class EnvironmentListProtectionSourcesRegistrationInfoEnum(object):

    """Implementation of the 'environment_ListProtectionSourcesRegistrationInfo' enum.

    TODO: type enum description here.

    Attributes:
        KVMWARE: TODO: type description here.
        KSQL: TODO: type description here.
        KVIEW: TODO: type description here.
        KPUPPETEER: TODO: type description here.
        KPHYSICAL: TODO: type description here.
        KPURE: TODO: type description here.
        KNETAPP: TODO: type description here.
        KGENERICNAS: TODO: type description here.
        KHYPERV: TODO: type description here.
        KACROPOLIS: TODO: type description here.
        KAZURE: TODO: type description here.
        KPHYSICALFILES: TODO: type description here.
        KISILON: TODO: type description here.
        KGPFS: TODO: type description here.
        KKVM: TODO: type description here.
        KAWS: TODO: type description here.
        KEXCHANGE: TODO: type description here.
        KHYPERVVSS: TODO: type description here.
        KORACLE: TODO: type description here.
        KGCP: TODO: type description here.
        KFLASHBLADE: TODO: type description here.
        KAWSNATIVE: TODO: type description here.
        KVCD: TODO: type description here.
        KO365: TODO: type description here.
        KO365OUTLOOK: TODO: type description here.
        KHYPERFLEX: TODO: type description here.
        KGCPNATIVE: TODO: type description here.
        KKUBERNETES: TODO: type description here.

    """

    K_VMWARE = 'kVMware'

    KSQL = 'kSQL'

    KVIEW = 'kView'

    KPUPPETEER = 'kPuppeteer'

    KPHYSICAL = 'kPhysical'

    KPURE = 'kPure'

    KNETAPP = 'kNetapp'

    KGENERICNAS = 'kGenericNas'

    K_HYPERV = 'kHyperV'

    KACROPOLIS = 'kAcropolis'

    KAZURE = 'kAzure'

    KPHYSICALFILES = 'kPhysicalFiles'

    KISILON = 'kIsilon'

    KGPFS = 'kGPFS'

    KKVM = 'kKVM'

    KAWS = 'kAWS'

    KEXCHANGE = 'kExchange'

    K_HYPERV_VSS = 'kHyperVVSS'

    KORACLE = 'kOracle'

    KGCP = 'kGCP'

    KFLASHBLADE = 'kFlashBlade'

    KAWSNATIVE = 'kAWSNative'

    KVCD = 'kVCD'

    KO365 = 'kO365'

    KO365OUTLOOK = 'kO365Outlook'

    KHYPERFLEX = 'kHyperFlex'

    KGCPNATIVE = 'kGCPNative'

    KKUBERNETES = 'kKubernetes'

==> cohesity_management_sdk-1.9.2.tar.gz: cohesity_management_sdk-1.9.2/cohesity_management_sdk/models/environment_list_protection_sources_registration_info_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class EnvironmentListProtectionSourcesRegistrationInfoEnum(object):

    """Implementation of the 'environment_ListProtectionSourcesRegistrationInfo' enum.

    TODO: type enum description here.

    Attributes:
        KVMWARE: TODO: type description here.
        KSQL: TODO: type description here.
        KVIEW: TODO: type description here.
        KPUPPETEER: TODO: type description here.
        KPHYSICAL: TODO: type description here.
        KPURE: TODO: type description here.
        KNETAPP: TODO: type description here.
        KGENERICNAS: TODO: type description here.
        KHYPERV: TODO: type description here.
        KACROPOLIS: TODO: type description here.
        KAZURE: TODO: type description here.
        KPHYSICALFILES: TODO: type description here.
        KISILON: TODO: type description here.
        KGPFS: TODO: type description here.
        KKVM: TODO: type description here.
        KAWS: TODO: type description here.
        KEXCHANGE: TODO: type description here.
        KHYPERVVSS: TODO: type description here.
        KORACLE: TODO: type description here.
        KGCP: TODO: type description here.
        KFLASHBLADE: TODO: type description here.
        KAWSNATIVE: TODO: type description here.
        KVCD: TODO: type description here.
        KO365: TODO: type description here.
        KO365OUTLOOK: TODO: type description here.
        KHYPERFLEX: TODO: type description here.
        KGCPNATIVE: TODO: type description here.
        KKUBERNETES: TODO: type description here.
        KCASSANDRA: TODO: type description here.
        KMONGODB: TODO: type description here.
        KCOUCHBASE: TODO: type description here.
        KHDFS: TODO: type description here.
        KHIVE: TODO: type description here.
        KHBASE: TODO: type description here.
        KUDA: TODO: type description here.

    """

    K_VMWARE = 'kVMware'

    KSQL = 'kSQL'

    KVIEW = 'kView'

    KPUPPETEER = 'kPuppeteer'

    KPHYSICAL = 'kPhysical'

    KPURE = 'kPure'

    KNETAPP = 'kNetapp'

    KGENERICNAS = 'kGenericNas'

    K_HYPERV = 'kHyperV'

    KACROPOLIS = 'kAcropolis'

    KAZURE = 'kAzure'

    KPHYSICALFILES = 'kPhysicalFiles'

    KISILON = 'kIsilon'

    KGPFS = 'kGPFS'

    KKVM = 'kKVM'

    KAWS = 'kAWS'

    KEXCHANGE = 'kExchange'

    K_HYPERV_VSS = 'kHyperVVSS'

    KORACLE = 'kOracle'

    KGCP = 'kGCP'

    KFLASHBLADE = 'kFlashBlade'

    KAWSNATIVE = 'kAWSNative'

    KVCD = 'kVCD'

    KO365 = 'kO365'

    KO365OUTLOOK = 'kO365Outlook'

    KHYPERFLEX = 'kHyperFlex'

    KGCPNATIVE = 'kGCPNative'

    KKUBERNETES = 'kKubernetes'

    KCASSANDRA = 'kCassandra'

    KMONGODB = 'kMongoDB'

    KCOUCHBASE = 'kCouchbase'

    KHDFS = 'kHdfs'

    KHIVE = 'kHive'

    KHBASE = 'kHBase'

    KUDA = 'kUDA'
